@@ -126,10 +126,10 @@ QStandardItem *AppearanceSettings::createSkinItem(const QString &skinDir)
     bool isKnsSkin = skinDir.startsWith(m_knsSkinDir);
 
     KConfig titleConfig(skinDir + QStringLiteral("/title.skin"), KConfig::SimpleConfig);
-    KConfigGroup titleDescription = titleConfig.group("Description");
+    KConfigGroup titleDescription = titleConfig.group(QStringLiteral("Description"));
 
     KConfig tabConfig(skinDir + QStringLiteral("/tabs.skin"), KConfig::SimpleConfig);
-    KConfigGroup tabDescription = tabConfig.group("Description");
+    KConfigGroup tabDescription = tabConfig.group(QStringLiteral("Description"));
 
     titleName = titleDescription.readEntry("Skin", "");
     titleAuthor = titleDescription.readEntry("Author", "");
@@ -422,11 +422,7 @@ void AppearanceSettings::knsDialogFinished(const QList<KNSCore::Entry> &changedE
     quint32 invalidEntryCount = 0;
     QString invalidSkinText;
     for (const auto &entry : changedEntries) {
-#if QT_VERSION_MAJOR < 6
-        auto Installed = KNS3::Entry::Installed;
-#else
         auto Installed = KNSCore::Entry::Installed;
-#endif
         if (entry.status() != Installed) {
             continue;
         }
