@@ -32,6 +32,7 @@
 #include <KStatusNotifierItem>
 #include <KToggleFullScreenAction>
 #include <KWindowEffects>
+#include <KWindowInfo>
 #include <KWindowSystem>
 #include <KX11Extras>
 
@@ -46,11 +47,7 @@
 #include <QWindow>
 
 #if HAVE_X11
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <private/qtx11extras_p.h>
-#endif
 
 #include <X11/Xlib.h>
 #include <fixx11h.h>
@@ -122,7 +119,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     connect(&m_mousePoller, SIGNAL(timeout()), this, SLOT(pollMouse()));
 
-    connect(KWindowSystem::self(), SIGNAL(workAreaChanged()), this, SLOT(applyWindowGeometry()));
+    connect(KX11Extras::self(), &KX11Extras::workAreaChanged, this, &MainWindow::applyWindowGeometry);
     connect(qApp, &QGuiApplication::screenAdded, this, &MainWindow::updateScreenMenu);
     connect(qApp, &QGuiApplication::screenRemoved, this, &MainWindow::updateScreenMenu);
 
@@ -603,7 +600,10 @@ void MainWindow::handleTerminalActivity(Terminal *terminal)
 
         QString message(xi18nc("@info", "Activity detected in monitored terminal in session \"%1\".", m_tabBar->tabTitle(session->id())));
 
-        KNotification::event(QLatin1String("activity"), message, QPixmap(), terminal->partWidget(), KNotification::CloseWhenWidgetActivated);
+        KNotification *n = new KNotification(QLatin1String("activity"), KNotification::CloseWhenWindowActivated);
+        n->setWindow(terminal->partWidget()->window()->windowHandle());
+        n->setText(message);
+        n->sendEvent();
     }
 }
 
@@ -614,7 +614,10 @@ void MainWindow::handleTerminalSilence(Terminal *terminal)
     if (session) {
         QString message(xi18nc("@info", "Silence detected in monitored terminal in session \"%1\".", m_tabBar->tabTitle(session->id())));
 
-        KNotification::event(QLatin1String("silence"), message, QPixmap(), terminal->partWidget(), KNotification::CloseWhenWidgetActivated);
+        KNotification *n = new KNotification(QLatin1String("silence"), KNotification::CloseWhenWindowActivated);
+        n->setWindow(terminal->partWidget()->window()->windowHandle());
+        n->setText(message);
+        n->sendEvent();
     }
 }
 
@@ -669,10 +672,10 @@ void MainWindow::handleToggleTitlebar()
 void MainWindow::setupMenu()
 {
     m_menu->insertSection(nullptr, xi18nc("@title:menu", "Help"));
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::WhatsThis))));
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::ReportBug))));
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::AboutApp))));
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::AboutKDE))));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::WhatsThis)));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::ReportBug)));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::AboutApp)));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::AboutKDE)));
 
     m_menu->insertSection(nullptr, xi18nc("@title:menu", "Quick Options"));
     m_menu->addAction(actionCollection()->action(QStringLiteral("view-full-screen")));
@@ -695,12 +698,12 @@ void MainWindow::setupMenu()
 
     m_menu->insertSection(nullptr, xi18nc("@title:menu", "Settings"));
     m_menu->addAction(actionCollection()->action(QStringLiteral("manage-profiles")));
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::KeyBindings))));
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::ConfigureNotifications))));
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Preferences))));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::KeyBindings)));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::ConfigureNotifications)));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Preferences)));
 
     m_menu->addSeparator();
-    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
+    m_menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
 }
 
 void MainWindow::updateScreenMenu()
@@ -881,11 +884,7 @@ void MainWindow::applySettings()
 
         // Prevent the default implementation of showing
         // and instead run toggleWindowState
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        m_notifierItem->setAssociatedWidget(nullptr);
-#else
         m_notifierItem->setAssociatedWindow(nullptr);
-#endif
         connect(m_notifierItem, &KStatusNotifierItem::activateRequested, this, &MainWindow::toggleWindowState);
         updateTrayTooltip();
     }
@@ -931,10 +930,11 @@ void MainWindow::applyWindowProperties()
 {
     if (m_isX11) {
         if (Settings::keepOpen() && !Settings::keepAbove()) {
-            KWindowSystem::clearState(winId(), NET::KeepAbove);
-            KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
-        } else
-            KWindowSystem::setState(winId(), NET::KeepAbove | NET::SkipTaskbar | NET::SkipPager);
+            KX11Extras::clearState(winId(), NET::KeepAbove);
+            KX11Extras::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+        } else {
+            KX11Extras::setState(winId(), NET::KeepAbove | NET::SkipTaskbar | NET::SkipPager);
+        }
     }
 
 #if HAVE_KWAYLAND
